==> haskell-typst-0.5.0.4-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-typst.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 typst
version:              0.5.0.4
visibility:           public
id:                   typst-0.5.0.4-A3UxhkzO5h21nM6bAgS6in
key:                  typst-0.5.0.4-A3UxhkzO5h21nM6bAgS6in
license:              BSD-3-Clause
copyright:            Copyright 2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Parsing and evaluating typst syntax.
description:
    A library for parsing and evaluating typst syntax.
    Typst (<https://typst.app>) is a document layout and
    formatting language. This library targets typst 0.10
    and currently offers only partial support.

category:             Text
abi:                  b87fe790aba218a8c472935c20bfda5a
exposed:              True
exposed-modules:
    Typst Typst.Evaluate Typst.Methods Typst.Parse Typst.Syntax
    Typst.Types Typst.Util

hidden-modules:
    Typst.Bind Typst.Regex Typst.Show Typst.Module.Standard
    Typst.Module.Math Typst.Module.Calc Typst.MathClass

import-dirs:          /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typst
hs-libraries:         HStypst-0.5.0.4-A3UxhkzO5h21nM6bAgS6in
depends:
    aeson-2.1.2.1-4RB85zdNr5p3whZ1np3a31 array-0.5.4.0 base-4.17.2.1
    bytestring-0.11.5.3 cassava-0.5.4.1-CA078skmoukJc2G96jmiZd
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    ordered-containers-0.2.4-I1D5gFD97QkEis5smlAj0D parsec-3.1.16.1
    pretty-1.1.3.6 regex-tdfa-1.3.2.4-8SMpKQokk9j1XbuNe0lCm6
    scientific-0.3.8.0-75VbuY3tmfA8QFAgCCeEHk text-2.0.2 time-1.12.2
    toml-parser-2.0.1.2-7KbhbFBg0EO6VqraIKCvU1
    typst-symbols-0.1.6-8fTeUIeuBH16qqbNakBZL7
    vector-0.13.2.0-B3Rnif6nhJNLHPAZlzHp2g
    xml-conduit-1.9.1.4-L3t63sJZHUiEjqyJCFyE7u
    yaml-0.11.11.2-1rOXYhv7h9B3GT9PBryEjl

haddock-interfaces:   /usr/share/doc/haskell-typst/html/typst.haddock
haddock-html:         /usr/share/doc/haskell-typst/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-typst-0.5.0.4-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-typst.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 typst
version:              0.5.0.4
visibility:           public
id:                   typst-0.5.0.4-FHD1gy81BMSvlB82ZP19B
key:                  typst-0.5.0.4-FHD1gy81BMSvlB82ZP19B
license:              BSD-3-Clause
copyright:            Copyright 2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Parsing and evaluating typst syntax.
description:
    A library for parsing and evaluating typst syntax.
    Typst (<https://typst.app>) is a document layout and
    formatting language. This library targets typst 0.10
    and currently offers only partial support.

category:             Text
abi:                  495a7b73edaa610a9b76d324c6c27e0a
exposed:              True
exposed-modules:
    Typst Typst.Evaluate Typst.Methods Typst.Parse Typst.Syntax
    Typst.Types Typst.Util

hidden-modules:
    Typst.Bind Typst.Regex Typst.Show Typst.Module.Standard
    Typst.Module.Math Typst.Module.Calc Typst.MathClass

import-dirs:          /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typst
hs-libraries:         HStypst-0.5.0.4-FHD1gy81BMSvlB82ZP19B
depends:
    aeson-2.1.2.1-CoFGCad0PesDH4XC5ctCv4 array-0.5.4.0 base-4.17.2.1
    bytestring-0.11.5.3 cassava-0.5.4.1-8r492bYlKNjDW3rnabaOuW
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    ordered-containers-0.2.4-D39GjPCcE4961TkCwi7OFE parsec-3.1.16.1
    pretty-1.1.3.6 regex-tdfa-1.3.2.4-EAViH0SVePPGm2eZt2I5vM
    scientific-0.3.8.0-3ah0qUGLDw61YSMhCVhWLa text-2.0.2 time-1.12.2
    toml-parser-2.0.1.2-CCrfzXt7cyZAsOCMYEEKev
    typst-symbols-0.1.6-8fTeUIeuBH16qqbNakBZL7
    vector-0.13.2.0-7UWGIXxclbLLOjGg0s2qXt
    xml-conduit-1.9.1.4-1ZIfFj0ZGuFFWAbq6vXb0B
    yaml-0.11.11.2-DOTRoIN69iI8VkvsxHJhD8

haddock-interfaces:   /usr/share/doc/haskell-typst/html/typst.haddock
haddock-html:         /usr/share/doc/haskell-typst/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
